from django.conf import settings
from django.conf.urls import include, url
from django.conf.urls.static import static
from django.contrib import admin
from django.http import HttpResponse

from fiber.views import page

admin.autodiscover()

urlpatterns = [
    url(r'^api/v2/', include('fiber.rest_api.urls')),
    url(r'^admin/fiber/', include('fiber.admin_urls')),

    url(r'^admin/', admin.site.urls),
]

if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

urlpatterns += [
    url(r'^empty/$', lambda request: HttpResponse('<!doctype html><html><head></head><body></body></html>')),
    url(r'', page),
]



from __future__ import unicode_literals

import django
from django.test import RequestFactory
from django.http import HttpResponse


class TestNewStyleMiddlewareMixin(object):
    middleware_factory = NotImplemented

    if django.VERSION >= (1, 10):
        def test_new_style(self):
            payload = b'Test'
            def get_response(request):
                return HttpResponse(payload)
            request = RequestFactory().get('/')

            callable_middleware = self.middleware_factory(get_response)
            self.assertEqual(callable_middleware(request).content,
                             payload)



from django.conf.urls import url

from . import views


urlpatterns = [
    url(r'^$', views.api_root),
    url(r'^pages/$', views.PageList.as_view(), name='page-list'),
    url(r'^pages/(?P<pk>[^/]+)/$', views.PageDetail.as_view(), name='page-detail'),
    url(r'^pages/(?P<pk>[^/]+)/move_page/$', views.MovePageView.as_view(), name='page-move'),
    url(r'^pagetree/$', views.PageTree.as_view(), name='pagetree'),
    url(r'^contentitemgroups/$', views.ContentItemGroups.as_view(), name='contentitemgroups'),
    url(r'^page_content_items/$', views.PageContentItemList.as_view(), name='pagecontentitem-list'),
    url(r'^page_content_items/(?P<pk>[^/]+)/$', views.PageContentItemDetail.as_view(), name='pagecontentitem-detail'),
    url(r'^page_content_items/(?P<pk>[^/]+)/move/$', views.MovePageContentItemView.as_view(), name='pagecontentitem-move'),
    url(r'^content_items/$', views.ContentItemList.as_view(), name='contentitem-list'),
    url(r'^content_items/(?P<pk>[^/]+)/$', views.ContentItemDetail.as_view(), name='contentitem-detail'),
    url(r'^images/$', views.ImageList.as_view(), name='image-list'),
    url(r'^images/(?P<pk>[^/]+)/$', views.ImageDetail.as_view(), name='image-detail'),
    url(r'^files/$', views.FileList.as_view(), name='file-list'),
    url(r'^files/(?P<pk>[^/]+)/$', views.FileDetail.as_view(), name='file-detail'),
]



from django.conf.urls import url
from django.views.i18n import JavaScriptCatalog

from . import admin_views
from . import fiber_admin

urlpatterns = [
    url(r'^page/(?P<id>\d+)/move_up/$', admin_views.page_move_up, name='fiber_page_move_up'),
    url(r'^page/(?P<id>\d+)/move_down/$', admin_views.page_move_down, name='fiber_page_move_down'),
    url(r'^login/$', admin_views.fiber_login, name='fiber_login'),
    url(r'^pages.json$', admin_views.pages_json, name='pages_json'),
    url(r'^fiber_admin/', fiber_admin.site.urls),
    url(r'^jsi18n/$', JavaScriptCatalog.as_view(), {'packages': 'fiber'}, name='fiber_i18n'),
]
